@@ -1,4 +1,5 @@
 from dataclasses import dataclass, field
+import re
 from typing import Callable
 
 from api_project_generator.functions import get_python_version
@@ -38,3 +39,8 @@ class PyprojectToml:
 
     def get_optional_dependencies(self, parser: Callable[[str], str]):
         return "\n" + "\n".join(parser(item) for item in self._optional_dependencies)
+
+    def get_project_title(self):
+        string = self.project_name.replace("-", " ").replace("_", " ")
+        string = re.sub("([a-z])([A-Z])", lambda match: f"{match[1]} {match[2]}", string)
+        return string.title()
\ No newline at end of file
